@@ -8,8 +8,10 @@ package fdrdf::module::file;
 use strict;
 use warnings;
 
+use RDF::Redland;
+
+use fdrdf::proto::io;
 use fdrdf::util;
-use fdrdf::module;
 
 BEGIN {
     use Exporter ();
@@ -18,14 +20,30 @@ BEGIN {
     # set the version for version checking
     $VERSION = 0.1;
 
-    @ISA = qw (Exporter);
-    @EXPORT = qw (&new);
+    @ISA = qw (Exporter fdrdf::proto::io);
+    @EXPORT = qw ();
     %EXPORT_TAGS = ();
     @EXPORT_OK = qw ();
+
+    ## URI's and prefixes
+    our $module_uri_s
+        = "uuid:be8202c2-bbbc-11df-a158-4040a5e6bfa3";
+    our $conf_prefix
+        = $module_uri_s . "#cf.";
+    our $desc_prefix
+        = "uuid:a2cb5fd0-4e89-4d8a-a009-dc42c45bbcc5#file.";
+    our $mime_type_uri_s
+        = $desc_prefix . "mime-type";
 }
 
-sub process_file {
-    my ($relation, $model, $subject, $io) = @_;
+## NB: not an OO method
+sub uri_node {
+    ## .
+    return new RDF::Redland::URINode (@_);
+}
+
+sub process_io {
+    my ($self, $model, $subject, $io) = @_;
 
     drop_cloexec ($io);
     my @cmd
@@ -40,24 +58,28 @@ sub process_file {
     chop;
     my $type = $_;
     my $s = $subject;
-    my $p = $relation;
+    my $p = $self->{"rel.mime-type"};
     my $o = new RDF::Redland::LiteralNode ("" . $type);
 
     $model->add_statement ($s, $p, $o);
 }
 
 sub new {
-    my ($pkg, $e_ref, $config) = @_;
-    my $relation_uri_s
-        = ("uuid:a2cb5fd0-4e89-4d8a-a009-dc42c45bbcc5#"
-           . "file.mime-type");
-    my $relation
-        = new RDF::Redland::URINode ($relation_uri_s);
-    my @handle = (\&process_file, $relation);
-    module_add_to_tag ($e_ref, "io", \@handle);
+    my ($class, $config) = @_;
+
+    our ($module_uri_s, $conf_prefix);
+    our ($desc_prefix,  $mime_type_uri_s);
+    my $self = {
+        "module"    => uri_node ($module_uri_s),
+        "conf_pfx"  => $conf_prefix,
+        "desc_pfx"  => $desc_prefix
+    };
+    $self->{"rel.mime-type"} = uri_node ($mime_type_uri_s);
+
+    bless ($self, $class);
 
     ## .
-    return $e_ref;
+    $self;
 }
 
 1;
